@@ -14,7 +14,7 @@ Version 1.01
 
 =cut
 
-our $VERSION = '1.01';
+our $VERSION = '1.1';
 
 
 =head1 SYNOPSIS
@@ -297,143 +297,135 @@ Tk::Widget->Construct('JDialog');
 
 sub Populate
 {
+	# Dialog object constructor.  Uses `new' method from base class
+	# to create object container then creates the dialog toplevel.
 
-    # Dialog object constructor.  Uses `new' method from base class
-    # to create object container then creates the dialog toplevel.
+	my($cw, $args) = @_;
 
-    my($cw, $args) = @_;
+	$cw->SUPER::Populate($args);
 
-    $cw->SUPER::Populate($args);
+	my ($w_bitmap,$w_but,$pad1,$pad2,$underlinepos,$mychar,$blshow,$i);
+	my ($btnopt,$undopt,$balloon);
 
-    my ($w_bitmap,$w_but,$pad1,$pad2,$underlinepos,$mychar,$blshow,$i);
-    my ($btnopt,$undopt,$balloon);
+	my $buttons = delete $args->{'-buttons'};
+	my $images = delete $args->{'-images'};
+	$buttons = ['OK']  unless (defined $buttons);
+	my $default_button = delete $args->{-default_button};
+	my $escape_button = delete $args->{-escape_button};
+	my $noballoons = delete $args->{-noballoons};
+	$useBalloon = 0  if ($noballoons);
+	$default_button = $buttons->[0] unless (defined $default_button);
 
-    my $buttons = delete $args->{'-buttons'};
-    my $images = delete $args->{'-images'};
-    $buttons = ['OK'] unless (defined $buttons);
-    my $default_button = delete $args->{-default_button};
-    my $escape_button = delete $args->{-escape_button};
-    my $noballoons = delete $args->{-noballoons};
-    $useBalloon = 0  if ($noballoons);
-    $default_button =  $buttons->[0] unless (defined $default_button);
+	# Create the Toplevel window and divide it into top and bottom parts.
 
-    # Create the Toplevel window and divide it into top and bottom parts.
+	$cw->{'selected_button'} = '';
+	my (@pl) = (-side => 'top', -fill => 'both');
+	($pad1, $pad2) =
+	([-padx => '3m', -pady => '3m'], [-padx => '3m', -pady => '2m']);
 
-    $cw->{'selected_button'} = '';
-    my (@pl) = (-side => 'top', -fill => 'both');
-    ($pad1, $pad2) =
-        ([-padx => '3m', -pady => '3m'], [-padx => '3m', -pady => '2m']);
-
-    $cw->withdraw;
-    $cw->iconname('JDialog');
-    $cw->protocol('WM_DELETE_WINDOW' => sub {});
+	$cw->withdraw;
+	$cw->iconname('JDialog');
+	$cw->protocol('WM_DELETE_WINDOW' => sub {});
 #?????????????????    $cw->transient($cw->toplevel)  unless ($^O =~ /Win/i);
 
-    my $w_top = $cw->Frame(Name => 'top',-relief => 'raised', -borderwidth => 1);
-    my $w_bot = $cw->Frame(Name => 'bot',-relief => 'raised', -borderwidth => 1);
-    $w_top->pack(@pl);
-    $w_bot->pack(@pl);
+	my $w_top = $cw->Frame(Name => 'top',-relief => 'raised', -borderwidth => 1);
+	my $w_bot = $cw->Frame(Name => 'bot',-relief => 'raised', -borderwidth => 1);
+	$w_top->pack(@pl);
+	$w_bot->pack(@pl);
 
-    # Fill the top part with the bitmap and message.
+	# Fill the top part with the bitmap and message.
 
-    @pl = (-side => 'left');
+	@pl = (-side => 'left');
 
-    $w_bitmap = $w_top->Label(Name => 'bitmap');
-    $w_bitmap->pack(@pl, @$pad1);
-    my $w_msg = $w_top->Label(
-	#-wraplength => '3i',    --!!! Removed 2/19 by Jim Turner
-	-justify    => 'left' );
+	$w_bitmap = $w_top->Label(Name => 'bitmap');
+	$w_bitmap->pack(@pl, @$pad1);
+	my $w_msg = $w_top->Label(
+			#-wraplength => '3i',    --!!! Removed 2/19 by Jim Turner
+			-justify    => 'left' 
+	);
 
-    $w_msg->pack(-side => 'right', -expand => 1, -fill => 'both', @$pad1);
+	$w_msg->pack(-side => 'right', -expand => 1, -fill => 'both', @$pad1);
 
-    # Create a row of buttons at the bottom of the dialog.
+	# Create a row of buttons at the bottom of the dialog.
 
-    my($w_default_button, $bl) = (undef, '');
-    $cw->{'default_button'} = undef;
-    $cw->{'escape_button'} = undef;
-    $i = 0;
-    foreach $bl (@$buttons) {
+	my ($w_default_button, $bl) = (undef, '');
+	$cw->{'default_button'} = undef;
+	$cw->{'escape_button'} = undef;
+	$i = 0;
+	foreach $bl (@$buttons) {
+		$blshow = $bl;
+		$underlinepos = ($blshow =~ s/^(.*)~/$1/) ? length($1): undef;
+		if (defined($$images[$i]) && $$images[$i] gt ' ' && -e $$images[$i]) {		
+			$cw->Photo($blshow, -file => $$images[$i]);
+			$btnopt = '-image';
+		} else {
+			$btnopt = '-text';
+		}
+		if (defined($underlinepos)) {		
+			$mychar = substr($blshow,$underlinepos,1);
+			$w_but = $w_bot->Button(
+				$btnopt => $blshow,
+				-underline => $underlinepos,
+				-command => [
+					sub {
+						$_[0]->{'selected_button'} = $_[1];
+					}, $cw, $bl,
+				]
+			);
+			$cw->bind("<Alt-\l$mychar>", [$w_but => "Invoke"]);
+			$cw->bind("<Key-\l$mychar>", [$w_but => "Invoke"]);
+		} else {
+			$w_but = $w_bot->Button(
+				$btnopt => $blshow,
+				-command => [
+				sub {
+					$_[0]->{'selected_button'} = $_[1];
+					}, $cw, $bl,
+				]
+			);
+		}
+		if ($useBalloon && $btnopt eq '-image') {
+		
+			$balloon = $cw->Balloon();
+			$balloon->attach($w_but, -state => 'balloon', -balloonmsg => $blshow);
+		}
+		if ($bl eq $default_button) {
+			$w_default_button = $w_bot->Frame(
+					-relief      => 'sunken',
+					-borderwidth => 1
+			);
+			$w_but->raise($w_default_button);
+			$w_default_button->pack(@pl, -expand => 1, @$pad2);
+			$w_but->pack(-in => $w_default_button, -padx => '2m',
+					-pady => '2m'
+			);
 
-	$blshow = $bl;
-	$underlinepos = ($blshow =~ s/^(.*)~/$1/) ? length($1): undef;
-	if (defined($$images[$i]) && $$images[$i] gt ' ' && -e $$images[$i])
-	{
-		$cw->Photo($blshow, -file => $$images[$i]);
-		$btnopt = '-image';
-	}
-	else
-	{
-		$btnopt = '-text';
-	}
-	if (defined($underlinepos))
-	{
-		$mychar = substr($blshow,$underlinepos,1);
-		$w_but = $w_bot->Button(
-		    $btnopt => $blshow,
-		    -underline => $underlinepos,
-		    -command => [
-			sub {
-			    $_[0]->{'selected_button'} = $_[1];
-			}, $cw, $bl,
-		    ]
-		);
-		$cw->bind("<Alt-\l$mychar>", [$w_but => "Invoke"]);
-		$cw->bind("<Key-\l$mychar>", [$w_but => "Invoke"]);
-	}
-	else
-	{
-		$w_but = $w_bot->Button(
-		    $btnopt => $blshow,
-		    -command => [
-			sub {
-			    $_[0]->{'selected_button'} = $_[1];
-			}, $cw, $bl,
-		    ]
-		);
-	}
-	if ($useBalloon && $btnopt eq '-image')
-	{
-		$balloon = $cw->Balloon();
-		$balloon->attach($w_but, -state => 'balloon', -balloonmsg => $blshow);
-	}
-        if ($bl eq $default_button) {
-            $w_default_button = $w_bot->Frame(
-                -relief      => 'sunken',
-                -borderwidth => 1
-            );
-            $w_but->raise($w_default_button);
-            $w_default_button->pack(@pl, -expand => 1, @$pad2);
-            $w_but->pack(-in => $w_default_button, -padx => '2m',
-                         -pady => '2m');
-    	    $cw->{'default_button'} = $w_but;
-goto JWT_SKIP1;
-            $cw->bind(
-                '<Return>' => [
-                    sub {
-                        $_[1]->flash; 
-                        $_[2]->{'selected_button'} = $_[3];
-                    }, $w_but, $cw, $bl,
-                ]
-            );
-JWT_SKIP1:
-        } else {
-            $w_but->pack(@pl, -expand => 1, @$pad2);
-    	    $cw->{'default_button'} = $w_but  unless(defined($cw->{'default_button'}));
-        }
-	if ($bl eq $escape_button)
-	{
-            $cw->{'escape_button'} = $w_but;
-            $cw->bind('<Escape>' => [$w_but => "Invoke"]);
-	}
-        ++$i;
-    } # forend all buttons
+			$cw->{'default_button'} = $w_but;
+			goto JWT_SKIP1;
+			$cw->bind(
+					'<Return>' => [
+						sub {
+							$_[1]->flash; 
+							$_[2]->{'selected_button'} = $_[3];
+						}, $w_but, $cw, $bl,
+					]
+			);
+			JWT_SKIP1:
+		} else {
+			$w_but->pack(@pl, -expand => 1, @$pad2);
+			$cw->{'default_button'} = $w_but  unless(defined($cw->{'default_button'}));
+		}
+		if ($bl eq $escape_button) {
+			$cw->{'escape_button'} = $w_but;
+			$cw->bind('<Escape>' => [$w_but => "Invoke"]);
+		}
+		++$i;
+	} # end for all buttons
 
-    $cw->Advertise(message => $w_msg);
-    $cw->Advertise(bitmap  => $w_bitmap );
-    #!!!$cw->{'default_button'} = $w_default_button;
-
-	if ($^O =~ /Win/i)
-	{
+	$cw->Advertise(message => $w_msg);
+	$cw->Advertise(bitmap  => $w_bitmap );
+	#!!!$cw->{'default_button'} = $w_default_button;
+	if ($^O =~ /Win/i) {
 		$cw->ConfigSpecs(
 				-image      => ['bitmap',undef,undef,undef],
 				-bitmap     => ['bitmap',undef,undef,undef],
@@ -441,11 +433,9 @@ JWT_SKIP1:
 				-foreground => ['ADVERTISED','foreground','Foreground','black'],
 				-bg         => ['DESCENDANTS','background','Background',undef],
 				-background => ['DESCENDANTS','background','Background',undef],
-		DEFAULT     => ['message',undef,undef,undef]
+				DEFAULT     => ['message',undef,undef,undef]
 		);
-	}
-	else
-	{
+	} else {
 		$cw->ConfigSpecs(
 				-image      => ['bitmap',undef,undef,undef],
 				-bitmap     => ['bitmap',undef,undef,undef],
@@ -453,66 +443,58 @@ JWT_SKIP1:
 				-foreground => ['ADVERTISED','foreground','Foreground','black'],
 				-bg         => ['DESCENDANTS','background','Background',undef],
 				-background => ['DESCENDANTS','background','Background',undef],
-		# JWT for TNT!  -font       => ['message','font','Font','-*-Times-Medium-R-Normal-*-180-*-*-*-*-*-*'],
+				# JWT for TNT!  -font       => ['message','font','Font','-*-Times-Medium-R-Normal-*-180-*-*-*-*-*-*'],
 				-font       => ['message','font','Font','-adobe-helvetica-bold-r-normal--17-120-100-100-p-92-iso8859-1'],
-		DEFAULT     => ['message',undef,undef,undef]
+				DEFAULT     => ['message',undef,undef,undef]
 		);
 	}
 } # end Dialog constructor
 
-sub Show {
+sub Show {   	# Dialog object public method - display the dialog.
 
-    # Dialog object public method - display the dialog.
+	my ($cw, $grab_type) = @_;
 
-    my ($cw, $grab_type) = @_;
+	croak "Dialog:  `show' method requires at least 1 argument"
+			if scalar @_ < 1 ;
 
-    croak "Dialog:  `show' method requires at least 1 argument"
-        if scalar @_ < 1 ;
+	my $old_focus = $cw->focusSave;  # don't need (Jim Turner) after fixing BUG!
+	my $old_grab  = $cw->grabSave;
 
-    my $old_focus = $cw->focusSave;  # don't need (Jim Turner) after fixing BUG!
-    my $old_grab  = $cw->grabSave;
+	# Update all geometry information, center the dialog in the display
+	# and deiconify it
 
-    # Update all geometry information, center the dialog in the display
-    # and deiconify it
+	$cw->Popup(); 
 
-    $cw->Popup(); 
-
-    # set a grab and claim the focus.
-
-    if (defined $cw->{'default_button'}) 
-     {
-      $cw->{'default_button'}->focus;
-     } 
-    else
-     {
-      $cw->focus;
-     }
-	if ($ENV{DESKTOP_SESSION} =~ /AfterStep version 2.2.1[2-9]/io) {  #JWT:ADDED 20140606 B/C TO GET AFTERSTEP TO GIVE "TRANSIENT" WINDOWS THE FOCUS?!
-#		no strict 'subs';
-		Tk::Event::DoOneEvent(ALL_EVENTS);
-		select(undef, undef, undef, 0.25);  #FANCY QUICK-NAP FUNCTION!
+	# set a grab and claim the focus.
+	if (defined $cw->{'default_button'}) { 
+		$cw->{'default_button'}->focus;
+	} else {
+		$cw->focus;
 	}
-	unless ($ENV{DESKTOP_SESSION} =~ /kde/o)
-		 {
-	    if (defined $grab_type && length $grab_type) {
-	        $cw->grab($grab_type)  if ($grab_type !~ /no/io);  #JWT: ADDED 20010517 TO ALLOW NON-GRABBING!
-	    } else {
-	        $cw->grab;
-	    }
+	unless (!defined($ENV{DESKTOP_SESSION}) || $ENV{DESKTOP_SESSION} =~ /kde/o) {
+		if ($ENV{DESKTOP_SESSION} =~ /AfterStep version 2.2.1[2-9]/io) {  #JWT:ADDED 20140606 B/C TO GET AFTERSTEP TO GIVE "TRANSIENT" WINDOWS THE FOCUS?!
+			Tk::Event::DoOneEvent(ALL_EVENTS);
+			select(undef, undef, undef, 0.25);  #FANCY QUICK-NAP FUNCTION!
+		}
+		if (defined $grab_type && length $grab_type) {
+			$cw->grab($grab_type)  if ($grab_type !~ /no/io);  #JWT: ADDED 20010517 TO ALLOW NON-GRABBING!
+		} else {
+			$cw->grab;
+		}
 	}
 ############## $cw->waitVisibility;  #SEEMS TO HANG ON NEWER TK'S.
 	$cw->update;
 
-    # Wait for the user to respond, restore the focus and grab, withdraw
-    # the dialog and return the label of the selected button.
+	# Wait for the user to respond, restore the focus and grab, withdraw
+	# the dialog and return the label of the selected button.
 
-    $cw->waitVariable(\$cw->{'selected_button'});
-    $cw->grabRelease;
-    $cw->withdraw;
-    &$old_focus  if ($ENV{DESKTOP_SESSION} =~ /AfterStep version 2.2.1[2-9]/io);   #FIXED BUG CAUSING COMPLETE SCREEN LOCKUP IF ANOTHER
-			#MOTIF APP (WINDOW) IS POPPED UP SHORTLY AFTERWARDS!
-    &$old_grab;
-    return $cw->{'selected_button'};
+	$cw->waitVariable(\$cw->{'selected_button'});
+	$cw->grabRelease;
+	$cw->withdraw;
+	&$old_focus  if (defined($ENV{DESKTOP_SESSION}) && $ENV{DESKTOP_SESSION} =~ /AfterStep version 2.2.1[2-9]/io);   #FIXED BUG CAUSING COMPLETE SCREEN LOCKUP IF ANOTHER
+	#MOTIF APP (WINDOW) IS POPPED UP SHORTLY AFTERWARDS!
+	&$old_grab;
+	return $cw->{'selected_button'};
 
 } # end Dialog show method
 
